#' Funci\enc{ó}{o}n que proyecta las tasas de mortalidad y los supervivientes de la tabla de mortalidad
#'
#' Esta función proyecta las tasas de mortalidad y los supervivientes de la tabla de mortalidad para los espacios geográficos de proyección por sexo, edad y período de proyección. 
#'
#' @param m.data data frame que contiene el espacio geográfico, el sexo, los extremos inferiores de los intervalos de edades, el período de tiempo, la población y las defunciones.
#' @param nn número de períodos que se van a proyectar.
#' @param reg valor alfanumérico de longitud 1 que indica el tipo de espacio bajo el que se aplican los valores de Coale-Demeny. Los valores posibles son W=OESTE, E=ESTE,
#' N=NORTE y S=SUR. Si no se especifica se toma el valor W que es el que corresponde a España.
#' @keywords demography
#' @export
#' @importFrom mgcv gam
#' @importFrom stats offset
#' @importFrom stats predict
#' @seealso \code{\link[demogal]{PMortalityReg}}, \code{\link[demogal]{PFertilityReg}}.
#' @return m.p array con las tasas de mortalidad proyectadas (espacio*sexo*edad*tiempo)
#' @return lesti data frame que contiene los supervivientes proyectados según el espacio geográfico, el sexo, los extremos inferiores de los intervalos de edad y el periodo de tiempo (espacio*sexo*edad*tiempo*supervivientes)
#' @references 
#' Durbán, M. (2012). Splines con Penalizaciones: Teoría y aplicaciones. Universidad Carlos III de Madrid. 
#' @encoding UTF-8
#' @examples
#' 
#' nn=15
#' m=PMortality(m.data.s,nn,reg="W")


PMortality <-function (m.data, nn,  reg="W") 
{
  # Predeclaración CRAN check
  # off <- NULL
  # ·························
  
  year=max(m.data[,4])+1
  tablas <- mortable(m.data, reg=reg)
  resultado <- a2d(tablas[ , , , ,"q",drop=FALSE])[,c(4,1,2,3,6)]
  resultado[,1:4]= lapply(resultado[,1:4], function(x) as.numeric(as.character(x)))
  resultado=resultado[order(resultado[2],resultado[1], resultado[3], resultado[4]), ] 
  names(resultado)=c("Tempo","CodEspazo","Sexo","x","q")
  ue = unique(resultado[, 2])
  us = unique(resultado[, 3])
  ui = unique(resultado[, 4])
  datf = NULL
  i=12
  k=1
  kk=0
  for (i in ue) {
    for (k in us) {
      for (kk in ui) {
         uu = subset(resultado, as.numeric(as.character(resultado[,2])) == i
                    & as.numeric(as.character(resultado[,3])) == k
                    & as.numeric(as.character(resultado[,4])) == kk)
        uus = loess(uu[, 5] ~uu[,1])$fitted
        datf1 = cbind(uu, uus)
        datf = rbind(datf, datf1)
      }
    }
  }
  datf[, 6] <- ifelse(datf[, 6] < 0, 0, datf[, 6])
  qesti=NULL
  for (i in ue) {
    for (k in us) {
      uu = subset(datf, as.numeric(as.character(datf[,2])) == i &
                    as.numeric(as.character(datf[,3])) == k)
      pobb=subset(m.data,as.numeric(as.character(m.data[,1])) == i &
                   as.numeric(as.character(m.data[,2])) == k)
      pobb=pobb[,c(-1,-2,-6)]
      uu=merge(uu,pobb,by.x=c(colnames(uu)[1],colnames(uu)[4]),by.y=c(names(pobb)[2],names(pobb)[1]))
      uu[,7]=log(uu[,7]) 
      names(uu)[7]="off"
      uu[uu[,6]>1,6]=1
    mod=gam(uus~ te(x,Tempo,k=c(10,10),bs=c("ps","ps"),m=2),offset(off),family="quasibinomial",data=uu)
#   mod=gam(uus~ s(x,bs="ps",m=2)+s(Tempo,bs="ps",m=2),family="quasibinomial",data=uu)  
#   mod=lme(log(uus) ~ Tempo,data=uu,random=~1 | x)
    a=(mod$fitted.values)
    new=expand.grid(Tempo=((year):(year + nn - 1)),x=ui)
    qest = predict(mod,newdata=new,type="response")
    #qest=exp(qest)/(1+exp(qest))
    a = cbind(new[,1],i,k,new[,2],qest)
    qesti=rbind(qesti,a)
    }
  }
  qesti[qesti[,4]==ui[length(ui)],5]=1
  
  colnames(qesti)=c("Tiempo","Espazo","Sexo","Edad","qest")
  rownames(qesti)=NULL
 
  lesti = NULL
  
  qesti=data.frame(qesti)

  for (i in 1:length(ue)) {
    for (k in 1:length(us)) {
      for (kk in 1:length(ui)) {
        uu = subset(qesti, as.numeric(as.character(qesti[,2])) == ue[i] &
                      as.numeric(as.character(qesti[,3])) == us[k] &
                      as.numeric(as.character(qesti[,4])) == ui[kk])
        if (kk > 1) 
          uuu = subset(lesti, as.numeric(as.character(lesti[,2])) == ue[i] &
                         as.numeric(as.character(lesti[,3])) == us[k] &
                         as.numeric(as.character(lesti[,4])) == ui[kk - 1])
        if (kk == 1) {
          uu = cbind(uu, ll=1e+05)
        }
        if (kk > 1) {
          uu = cbind(uu, ll=uuu[, 6] - uuu[, 7])
        }
        uu = cbind(uu, uu[, 6] * uu[, 5])
        lesti = rbind(lesti, uu)
      }
    }
  }
  lesti = lesti[, c(2, 3, 4, 1, 6)]
  lesti = as.data.frame(lesti)
  names(lesti) = names(m.data)[1:5]
  names(lesti)[ncol(lesti)] = "value"
  lesti[(lesti$value<0),5]=0
  l.p <- lesti[order(lesti[, 4], lesti[, 3], lesti[, 2], lesti[,1]), 1:5]
  q.esti <- as.data.frame(qesti)
  mesti = NULL
  for (i in 1:length(ue)) {
      for (k in 1:length(us)) {
      for (kk in 1:length(ui)) {
        uu = subset(q.esti, as.numeric(as.character(qesti[,2])) == ue[i] &
                      as.numeric(as.character(qesti[,3])) == us[k] &
                      as.numeric(as.character(qesti[,4])) == ui[kk])
        if (kk < length(ui)) 
          n = ui[kk + 1] - ui[kk]
        if (kk == length(ui)) 
          n = ui[kk] - ui[kk - 1]
        uu$m.p = uu[, 5]/(n * (1 - 1/2 * uu[, 5]))
        mesti = rbind(mesti, uu)
      }
    }
  }
  names(mesti)[1:4] <- names(m.data)[c(4,1,2,3)]
  mesti=mesti[,c(2,3,4,1,5,6)]
  m.p=d2a(list(sort(unique(mesti[,1])),sort(unique(mesti[,2])),sort(unique(mesti[,3])),sort(unique(mesti[,4]))),mesti)[[2]]
  
  result = list(Forecast.Mortality.Rate = m.p, Forecast.Survivor = lesti)
  return(result)
}

