#' Funci\enc{ó}{o}n que calcula el \enc{Í}{I}ndice sint\enc{é}{e}tico de fecundidad y el \enc{Í}{I}ndice sint\enc{é}{e}tico de emigraci\enc{ó}{o}n
#'
#' Esta función calcula el Índice sintético de fecundidad y el Índice sintético de emigración.
#'
#' @param data data frame que contiene el espacio, los extremos inferiores de los intervalos de edad, el periodo de tiempo, la población base para calcular las tasas y el evento (espacio*edad*tiempo*poblacion*evento).
#' @keywords demography
#' @export
#' @importFrom stats IQR
#' @seealso \code{\link[demogal]{PMortality}}, \code{\link[demogal]{PFertility}}.
#' @return isf array con el índice sintético de fecundidad o emigración (espacio*tiempo)
#' @return isf_ri array con el rango intercuartílico de las tasas (espacio*edad*tiempo)
#' @return div2 array con las tasas (espacio*edad*tiempo)
#' @references Instituto Galego de Estatística
#' @encoding UTF-8
#' @examples
#' 
#' ind=tr(b.data)[[1]]
#' 

tr<-function(data){
  stopifnot(length(data) == 5)
  names(data)=c("space", "age","year","pop","event")
  stopifnot(is.numeric(data$age) & is.numeric(data$year)& is.numeric(data$pop) &is.numeric(data$event))
  ages=sort(unique(data$age))
  arr= d2a(list(unique(data$space),ages, sort(unique(data$year)) ) , data)
  if (0 %in% ages)   dif = c(diff(ages), mean(diff(ages)))
  else   dif = c(mean(diff(ages)), diff(ages))
  dif=xar(dif,1,dim(arr$pop)[1])
  dif=xar(dif,3,dim(arr$pop)[3])
  dif=array(data=dif,dim=dim(arr$event))
  div=(arr$event/arr$pop) * dif
  div2= arr$event/arr$pop
  div[is.na(div)] = 0
  div[div == "Inf"] = 0
  div2[is.na(div2)] = 0
  div2[div2 == "Inf"] = 0
  isf = apply(div, c(1, 3), sum)
  isf_ri = try(apply(div2, c(1, 3), IQR))
  if ("try-error" %in% class(isf_ri)) {
    isf_ri = isf
  }
  #innecesarios
  #rownames(isf) = rownames(isf_ri) = dimnames(arr$pop)[1]
  #colnames(isf) = colnames(isf_ri) = dimnames(arr$pop)[3]
  
  result = list(isf=isf, isf_ri=isf_ri, div2=div2)
  return(result)
}

