#' Funci\enc{ó}{o}n que calcula la edad mediana a la maternidad
#'
#' Permite calcular la edad mediana a la maternidad a partir de datos de nacimientos agrupados por 
#' edad de la madre. 
#'
#' @param data data frame que contiene el espacio geográfico, los extremos inferiores de los intervalos de edad, el periodo de tiempo y los nacimientos (espacio*edad*tiempo*evento).
#' @keywords demography
#' @export
#' @seealso \code{\link[demogal]{PMortality}}, \code{\link[demogal]{PFertility}}.
#' @return medianas array con la edad mediana a la maternidad según las variables de clasificación (espacio*tiempo)
#' @references Instituto Galego de Estatística
#' @encoding UTF-8
#' @examples
#' 
#' data=b.data[,c(1:3,5)]
#' m=medianasg(data)
#'

medianasg<-function(data) { 
  lista=list(sort(unique(data[, 1])),sort(unique(data[,2])), sort(unique(data[, 3]))) 
  matriz_data=d2a(lista,data) 
  dimens=dim(matriz_data) 
  l2num=as.numeric(as.character(lista[[2]])) 
  intervalos=rbind(l2num, c(l2num[-1], 2*l2num[length(l2num)]-l2num[length(l2num)-1])) 
  GroupedMedian <- function(frequencies, intervals) { 
    Midpoints <- rowMeans(intervals) 
    cf <- cumsum(frequencies) 
    Midrow <- findInterval(max(cf)/2, cf) + 1 
    L <- intervals[1, Midrow] 
    h <- diff(intervals[, Midrow]) 
    f <- frequencies[Midrow] 
    cf2 <- cf[Midrow - 1] 
    n_2 <- max(cf)/2 
    return(L + (n_2 - cf2)/f * h) 
  } 
  
  medianas <- outer(1:length(lista[[1]]) , 1:length(lista[[3]]), 
                    function(a,b) mapply(function(i,j)GroupedMedian(matriz_data[i, ,j], intervalos),a,b) ) 
  rownames(medianas)<-lista[[1]] 
  colnames(medianas)<-lista[[3]] 
  return(medianas) 
} 

