#' Funci\enc{ó}{o}n para proyectar diferentes magnitudes de la fecundidad
#'
#' Esta función se usa para proyectar diferentes magnitudes de la fecundidad mediante una relación log-funcional de las mismas y el tiempo. Se utilizan n períodos para proyectar.
#'
#' @param nn número de períodos que se van a proyectar.
#' @param ma data frame que contiene el espacio, el período de tiempo y la magnitud de fecundidad que se proyecta (tasas, índices sintéticos,...) (espacio*tiempo*magnitud)
#' @keywords demography 
#' @export
#' @seealso \code{\link[demogal]{PMortality}}, \code{\link[demogal]{PFertility}}.
#' @return prox array con la magnitud proyectada (espacio*tiempo)
#' @references
#' Durbán, M. (2012). Splines con Penalizaciones: Teoría y aplicaciones. Universidad Carlos III de Madrid. 
#' @encoding UTF-8



project<-function(nn,ma){
  ue = unique(ma[, 1])
  n=length(unique(ma[, 2]))
  stopifnot(nrow(ma) == n*length(ue))
  expl = log(seq(1, (n+nn)))
  f<-function(e){
    aa = subset(ma, ma[, 1] == e)
    a = data.frame(ma = (aa[, 3]), logg = expl[1:n])
    names(a) = c("ma", "logg")
  
    regre=gam(ma~ s(logg,bs='ps'),data=a)
    re=predict(regre,newdata=data.frame(logg= expl[(n+1):(n+nn)]))
    if (length(re[re<0])>1){
#    predict(regre,data.frame=expl[(n+1):(n+nn)])
    regre = lm(ma ~ logg, a)
    ajuste = (aa[n - 2, 3] + aa[n - 1, 3] + aa[n, 3])/3
    ajuste = ajuste/(coef(regre)[1] + coef(regre)[2] * log(n+1))
    re=coef(regre)[1] + coef(regre)[2] * expl[(n+1):(n+nn)]*ajuste}
    return(re)
  }
  prox=t(sapply(ue, f))
  rownames(prox) = ue
  return(prox)
}



