% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/demogal-package.R
\docType{package}
\encoding{UTF-8}
\name{demogal}
\alias{demogal}
\alias{demogal-package}
\title{DEMOGAL}
\description{
La elaboración de indicadores demográficos y proyecciones de población es una tarea habitual 
de las oficinas de estadística pública porque, en todo tipo de planificación, es fundamental 
conocer la estructura demográfica actual y las perspectivas de evolución de la población.
Hoy en día existen herramientas informáticas que permiten el cálculo de indicadores y de 
las tablas de mortalidad de manera sencilla, como pueden ser EPIDAT, hojas de cálculo, etc. 
Estas herramientas, en algunos casos, no tienen la flexibilidad necesaria para adaptarse
a cualquier metodología de cálculo, en otros casos, no permiten procesar grandes conjuntos
de datos y, lo que es más importante, cuando se maneja gran cantidad de información, la mayor
parte de ellas no permiten automatizar el proceso de cálculo, etc. 
Teniendo en cuenta todas estas dificultades que plantean las herramientas existentes,
desde el Instituto Galego de Estatística (IGE) se pensó en aprovechar la flexibilidad de R 
para desarrollar un paquete que permitiese automatizar el cálculo de las funciones
demográficas que periódicamente se utilizan en el IGE para calcular indicadores y para 
proyectar flujos y stocks poblacionales. 
 
El método de este paquete para proyectar los flujos y stocks poblacionales parte de la población residente en un cierto ámbito geográfico (provincias, comarcas, etc.) y de los datos
observados para cada uno de las componentes demográficas básicas, la mortalidad, la fecundidad y la migración. 
Se trata de obtener la población correspondiente a fechas o períodos posteriores bajo ciertas hipótesis sobre la evolución de estos
tres fenómenos. 
La elaboración de estas proyecciones de población está basada en el método clásico de componentes, el cual, a partir de una población residente en un cierto espacio geográfico y de los 
datos observados para cada una de las componentes demográficas básicas (mortalidad, fecundidad y migración), permite obtener la población en períodos futuros bajo ciertas hipótesis 
sobre la evolución de las componentes, que son las que determinan el crecimiento de la población y su estructura por edades.
Se utiliza el modelo de proyección multirregional propuesto por Willekens, que proporciona las cifras de población residente y las cifras proyectadas de nacimientos, defunciones y 
movimientos migratorios que tendrán lugar en cada espacio considerado y para cada uno de los períodos del horizonte proyectivo, guardando todo ello la necesaria coherencia entre 
flujos y stocks demográficos y la debida consistencia interterritorial.
En este paquete se contemplan dos enfoques:
\itemize{
\item Proyección de la población para uno o más espacios geográficos aplicando el modelo multirregional.
\item Proyección de la población para varios espacios geográficos mediante el modelo multirregional, pero imponiendo que los datos agregados del conjunto de espacios coincidan con los de una proyección preexistente del área formada por el conjunto de los espacios (consistencia con el espacio superior).
}
}
\details{
Por tanto, se puede disponer de un espacio o varios que se desean proyectar y también se puede disponer de un espacio superior o varios. El método empleado permite
hacer una proyección coherente con los datos de los espacios superiores. En este último caso, el espacio o espacios superiores deben estar relacionados
jerárquicamene con los espacios de la proyección, por ejemplo, las provincias de Galicia como espacios de proyección y Galicia como espacio superior.
Como resumen, el método programado permite ajustar (si se desea) los datos finales a las posibles proyecciones disponibles de un espacio superior.

Este método empleado proyecta cada uno de los fenómenos demográficos por separado, para después unirlos en la obtención de la proyección de la población. 
Las hipótesis que se hayan planteado sobre cada uno de estos fenómenos demográficos se aplican a la población en el período de partida $t_0$, obteniendo la población en el
período $t_{0+1}$. Actuando así, de forma iterada, se llega al horizonte de la proyección, $t_{0+nn}$.
Para la obtención de la proyección de la población será necesario disponer de información de nacimientos, defunciones y movimientos migratorios correspondiente a los últimos $n$ períodos: $t_{0-n}, t_{0-(n-1)}, \ldots , t_{0-1}$.

El desarrollo de demogal está inspirado en la metodología de proyección empleada por el INE (2010).

En el ejemplo que se incluye en este paquete el objetivo es la proyección de la población de las 53 comarcas gallegas, tomando como base la población de 1 de enero del 2013 y proyectando la población para un horizonte de 15 años. Se utiliza como espacio superior las 4 provincias gallegas.
}
\references{
Durbán, M. (2012). Splines con Penalizaciones: Teoría y aplicaciones. Universidad Carlos III de Madrid.

Willekens, F.J. and Drew, P. (1984), A Multiregional Model for Regional Demographic Projection. Demographic
Research and Spatial Policy, Ch.15, pp. 309-331 - Academic Press, London.

Epidat: programa para análise epidemiolóxica de datos. Versión 4.0, xuño 2012. Consellería de Sanidade, Xunta de Galicia, España; Organización Panamericana de la Salud (OPS-OMS). Disponible en: http://dxsp.sergas.es

Vinuesa, J. y Puga, D. (2007), Técnicas y ejercicios de Demografía

Zeng Yi, Wang Zhenglian, Ma Zhongdong e Chen Chunjun. (2000). “A simple method for projecting or estimating alfa and beta: An extension of the Brass Relational Gompertz Fertility Model”, en Population Research and Policy Review 19: 525-549

Rob J Hyndman with contributions from Heather Booth, Leonie  Tickle and John Maindonald. (2014). demography: Forecasting   mortality, fertility, migration and population data. R package version 1.18. https://CRAN.R-project.org/package=demography

INE (2010). Proyección de la Población de España a Corto Plazo. Metodología
}

