% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/proxeccion.R
\encoding{UTF-8}
\name{projection}
\alias{projection}
\title{Funci\enc{ó}{o}n que proyecta la poblaci\enc{ó}{o}n para el per\enc{í}{i}odo de proyecci\enc{ó}{o}n}
\usage{
projection(nn, r, pop, m.rate.pr, f.rate.pr, migration, relation = NULL,
  pop.sup.pr = NULL, b.sup.pr = NULL, m.sup.pr = NULL)
}
\arguments{
\item{nn}{número de períodos que se van a proyectar.}

\item{r}{data frame que contiene el espacio de proyección, el sexo, los extremos inferiores de los intervalos de edades y la proporción de población promedio de los últimos n períodos de tiempo anteriores a la proyección que pasa de un grupo de edad a otro en el período siguiente (espacio*sexo*edad*proporcion).}

\item{pop}{data frame que contiene el espacio geográfico de proyección, el sexo, los extremos inferiores de los intervalos de edades, el período de tiempo y la población base de la proyección (espacio*sexo*edad*tiempo*poblacion).}

\item{m.rate.pr}{array con las tasas de mortalidad proyectadas, salida de la función \code{\link[demogal]{PMortality}} o \code{\link[demogal]{PMortalityReg}}.}

\item{f.rate.pr}{array con las tasas de fecundidad proyectadas, salida de la función \code{\link[demogal]{PFertility}} o \code{\link[demogal]{PFertilityReg}}.}

\item{migration}{list con las proyecciones de las tasas de emigración exterior (salida de la función \code{\link[demogal]{ExtEm}} o \code{\link[demogal]{ExtEmReg}}), los inmigrantes procedentes del exterior (salida de la función \code{\link[demogal]{ExtIn}}) y las tasas de emigración interior (salida de la función \code{\link[demogal]{IntEm}}). Si no se dispone de las tasas de emigración interior este elemento de la lista se pone igual a NULL.}

\item{relation}{data frame opcional que contiene las relaciones jerárquicas entre el espacio de la proyección y el espacio superior (primera columna, el espacio de la proyección; segunda columna, el espacio superior al de proyección). Las etiquetas de las filas serán las etiquetas del espacio de proyección.}

\item{pop.sup.pr}{data frame opcional que contiene el espacio superior, el sexo, los extremos inferiores de los intervalos de edades, el período de tiempo y la población proyectada para el espacio superior (espacio superior*sexo*edad*tiempo*poblacion).}

\item{b.sup.pr}{data frame opcional que contiene el espacio superior, el sexo, el período de tiempo y los nacimientos proyectados para el espacio superior (espacio superior*sexo*tiempo*nacimientos).}

\item{m.sup.pr}{data frame opcional que contiene el espacio superior, el sexo, el período de tiempo y las defunciones proyectadas para el espacio superior (espacio superior*sexo*edad*tiempo*defunciones).}
}
\value{
poblacion array con la población proyectada (espacio*sexo*edad*tiempo)

births array con los nacimientos proyectados (espacio*sexo*tiempo)

deaths array con las defunciones proyectadas (espacio*sexo*edad*tiempo)
}
\description{
Esta función proyecta la población para el espacio de proyección, sexo, edad y todo el período de proyección.
}
\examples{

nn=15
l.sup=PMortality(m.data.s,nn,reg="W")[[2]]
m.rate.pr=PMortalityReg(m.data,l.sup,relation,reg="W")
f.rate.pr=PFertilityReg(b.data,tfr.sup=NULL,nn,relation)

#EMIGRACIONES EXTERNAS
aux2=merge(emig.out,relation,by.x=names(emig.out)[1],by.y=names(relation)[1],all.x=TRUE)
emig.outt=aggregate(aux2[,c(5,6)],list(aux2[,7],aux2[,2],aux2[,3],aux2[,4]),sum)
names(emig.outt)=names(emig.out)
u=ExtEm(emig.outt,nn)
iset=u[[2]]
ise=u[[3]]
u=ExtEmReg(emig.out,iset,ise,relation,nn)

#INMIGRACIONES PROCEDENDES DEL EXTERIOR
v=ExtIn(imig.out,relation,nn,v_inmig=NULL)

#EMIGRACIONES INTERNAS
w=IntEm(emig.int,emig.intc,nn)
migration=list(u,v,w)

r<-expand.grid(unique(pop[,1]),unique(pop[,2]),unique(pop[,3])[2:21])
r[,4]=0.2
names(r)=c("comarca","sexo","Idadeq","dato")
m=projection(nn,r,pop,m.rate.pr,f.rate.pr,migration,relation=NULL)


 
}
\references{
Instituto Galego de Estatística
}
\seealso{
\code{\link[demogal]{PMortality}}, \code{\link[demogal]{PMortalityReg}}, \code{\link[demogal]{PFertility}}, \code{\link[demogal]{PFertilityReg}}.
}
\keyword{demography}

